Crate sqry_plugin_registry

Crate sqry_plugin_registry 

Shared plugin registry for SQRY

This module provides a centralized function to create a PluginManager with all built-in language plugins registered. This is the single source of truth for the supported plugin roster, used by CLI, index, and other consumers.

Auto-registration of Built-in Plugins

This module centralizes the registration of all 37 language plugins to ensure consistency across the entire ecosystem (CLI, LSP, MCP, etc.).

Functions

create_plugin_manager
Create a PluginManager with all built-in language plugins registered.