Shared plugin registry for SQRY
This module provides a centralized function to create a PluginManager with all
built-in language plugins registered. This is the single source of truth for
the supported plugin roster, used by CLI, index, and other consumers.
Auto-registration of Built-in Plugins
This module centralizes the registration of all 37 language plugins to ensure consistency across the entire ecosystem (CLI, LSP, MCP, etc.).
Functions
- create_
plugin_ manager - Create a
PluginManagerwith all built-in language plugins registered.